#region Imports

Import-Module Webadministration
$commonModule = Join-Path $PSScriptRoot "IISCommon.psm1"
Import-Module $commonModule

#endregion Imports

#region Variables

$hostName = "biatorbagyi.ekreta.hu"
$hostIp = "127.0.0.1"

$webPath = Join-Path $PSScriptRoot "..\..\KretaWeb"
$evaluatedWebPath = [System.IO.Path]::GetFullPath($webPath)

$webApiNaploPath = Join-Path $PSScriptRoot "..\..\Kreta.WebApi\Naplo\Kreta.Naplo.WebApi"
$evaluatedWebApiNaploPath = [System.IO.Path]::GetFullPath($webApiNaploPath)

$webApiEllenorzoPath = Join-Path $PSScriptRoot "..\..\Kreta.WebApi\Ellenorzo\Kreta.Ellenorzo.WebApi"
$evaluatedWebApiEllenorzoPath = [System.IO.Path]::GetFullPath($webApiEllenorzoPath)

$webApieUgyintezesPath = Join-Path $PSScriptRoot "..\..\Kreta.WebApi\eUgyintezes\Kreta.eUgyintezes.WebApi"
$evaluatedWebApieUgyintezesPath = [System.IO.Path]::GetFullPath($webApieUgyintezesPath)

$webApiUserPath = Join-Path $PSScriptRoot "..\..\Kreta.WebApi\User\Kreta.User.WebApi"
$evaluatedWebApiUserPath = [System.IO.Path]::GetFullPath($webApiUserPath)

$iisApplication = @{name="Kreta.Web";
  poolName="Kreta.Web";
  applicationPath=$evaluatedWebPath;
  bindings=@{protocol="https";bindingInformation=":443:" + $hostName;sslFlags=1};
  property=@{name="managedRuntimeVersion";value="v4.0"}}
  
$iisVirtualApplications = 
@{name="naplo";
  poolName="Kreta.Naplo.WebApi";
  applicationPath=$evaluatedWebApiNaploPath;
  needCertification=$false;
  property=@{name="managedRuntimeVersion";value="v4.0"}},
@{name="eugyintezes";
  poolName="Kreta.eUgyintezes.WebApi";
  applicationPath=$evaluatedWebApieUgyintezesPath;
  needCertification=$false;
  property=@{name="managedRuntimeVersion";value="v4.0"}},
@{name="user";
  poolName="Kreta.User.WebApi";
  applicationPath=$evaluatedWebApiUserPath;
  needCertification=$false;
  property=@{name="managedRuntimeVersion";value="v4.0"}},
@{name="ellenorzo";
  poolName="Kreta.Ellenorzo.WebApi";
  applicationPath=$evaluatedWebApiEllenorzoPath;
  needCertification=$false;
  property=@{name="managedRuntimeVersion";value="v4.0"}}

#endregion Variables

#region Main
  
try
{        
  Write-Host "---------------------Checking Administrator credentials--------------------------"
  $checkCredentials = CheckCredentials
  if($checkCredentials -eq $false)
  {
    exit
  }
  
  #Write-Host "---------------------Start Logging-----------------------------------------------"
  #StartLogging
  
  Write-Host "---------------------Enable embedded IIS features--------------------------------"
  EnableEmbeddedIISFeatures
  
  Write-Host "---------------------Scaffold IIS For KRETA--------------------------------------"
  ScaffoldIIS $hostName $hostIp $iisApplication $iisVirtualApplications
  
  Write-Host "---------------------Restart IIS-------------------------------------------------"
    ResetIIS

    Write-Host "---------------------Reset Environment-------------------------------------------"
    ResetEnvironment
}
finally
{
    Write-Host "---------------------Stop Logging------------------------------------------------"
    StopLogging
}

#endregion Main