﻿#region Imports
Import-Module Webadministration
$commonModule = Join-Path $PSScriptRoot "Common.psm1"
Import-Module $commonModule

#endregion

#region Variables for Kreta

$hostName = "biatorbagyi.ekreta.hu"
$hostIp = "127.0.0.1"
$iisApplicationPoolName = "Kreta.Web"
$iisApplicationPoolDotNetVersion = "v4.0"
$iisApplicationName = "Kreta.Web"
$webPath = Join-Path $PSScriptRoot "..\..\KretaWeb"
$evaluatedWebPath = [System.IO.Path]::GetFullPath($webPath)

#endregion

#region Variables for Kreta.Ellenorzo.WebApi

$hostNameForEllenorzoApi = "ellenorzo.ekreta.hu"
$hostIpForEllenorzoApi = "127.0.0.1"
$iisApplicationPoolNameForEllenorzoApi = "Kreta.Ellenorzo.WebApi"
$iisApplicationPoolDotNetVersionForEllenorzoApi = "v4.0"
$iisApplicationNameForEllenorzoApi = "Kreta.Ellenorzo.WebApi"
$webPathForEllenorzoApi = Join-Path $PSScriptRoot "..\..\Kreta.WebApi\Ellenorzo\Kreta.Ellenorzo.WebApi"
$evaluatedWebPathForEllenorzoApi = [System.IO.Path]::GetFullPath($webPathForEllenorzoApi)

#endregion

#region Variables for Kreta.Naplo.WebApi

$hostNameForNaploApi = "naplo.ekreta.hu"
$hostIpForNaploApi = "127.0.0.1"
$iisApplicationPoolNameForNaploApi = "Kreta.Naplo.WebApi"
$iisApplicationPoolDotNetVersionForNaploApi = "v4.0"
$iisApplicationNameForNaploApi = "Kreta.Naplo.WebApi"
$webPathForNaploApi = Join-Path $PSScriptRoot "..\..\Kreta.WebApi\Naplo\Kreta.Naplo.WebApi"
$evaluatedWebPathForNaploApi = [System.IO.Path]::GetFullPath($webPathForNaploApi)

#endregion

#region Variables for KretaMobileAPI

$hostNameForMobileApi = "mobileapi.ekreta.hu"
$hostIpForMobileApi = "127.0.0.1"
$iisApplicationPoolNameForMobileApi = "Kreta.Mobile.WebApi"
$iisApplicationPoolDotNetVersionForMobileApi = "v4.0"
$iisApplicationNameForMobileApi = "Kreta.Mobile.WebApi"
$webPathForMobileApi = Join-Path $PSScriptRoot "..\..\Kreta.Mobile.WebApi\Kreta.Mobile.WebApi"
$evaluatedWebPathForMobileApi = [System.IO.Path]::GetFullPath($webPathForMobileApi)

#endregion


#region Variables for KretaIdp

$hostNameForKretaIdp = "idp.ekreta.hu"
$hostIpForKretaIdp = "127.0.0.1"
$iisApplicationPoolNameForKretaIdp = "Kreta.IdentityProvider"
$iisApplicationPoolDotNetVersionForKretaIdp = "v4.0"
$iisApplicationNameForKretaIdp = "Kreta.IdentityProvider"
$webPathForKretaIdp = Join-Path $PSScriptRoot "..\..\Kreta.IdentityProvider\Kreta.IdentityProvider.WebApi"
$evaluatedWebPathForKretaIdp = [System.IO.Path]::GetFullPath($webPathForKretaIdp)
$localDbForIdp = "kreta_dev"

#endregion

#region Main

try
{
    Write-Host "---------------------Checking Administrator credentials--------------------------"
    $checkCredentials = CheckCredentials
    if($checkCredentials -eq $false)
    {
        exit
    }

    Write-Host "---------------------Start Logging-----------------------------------------------"
    StartLogging

    Write-Host "---------------------Enable embedded IIS features--------------------------------"
    EnableEmbeddedIISFeatures

    Write-Host "---------------------Scaffold IIS For Kreta--------------------------------------"
    ScaffoldIIS $hostName $hostIp $iisApplicationPoolName $iisApplicationPoolDotNetVersion $iisApplicationName $evaluatedWebPath

    Write-Host "---------------------Scaffold IIS For Mobile Api---------------------------------"
    ScaffoldIIS $hostNameForMobileApi $hostIpForMobileApi $iisApplicationPoolNameForMobileApi $iisApplicationPoolDotNetVersionForMobileApi $iisApplicationNameForMobileApi $evaluatedWebPathForMobileApi

	Write-Host "---------------------Scaffold IIS For Ellenorzo Api---------------------------------"
    ScaffoldIIS $hostNameForEllenorzoApi $hostIpForEllenorzoApi $iisApplicationPoolNameForEllenorzoApi $iisApplicationPoolDotNetVersionForEllenorzoApi $iisApplicationNameForEllenorzoApi $evaluatedWebPathForEllenorzoApi
	
	Write-Host "---------------------Scaffold IIS For Naplo Api---------------------------------"
    ScaffoldIIS $hostNameForNaploApi $hostIpForNaploApi $iisApplicationPoolNameForNaploApi $iisApplicationPoolDotNetVersionForNaploApi $iisApplicationNameForNaploApi $evaluatedWebPathForNaploApi
	
    Write-Host "---------------------Scaffold IIS For Idp----------------------------------------"
    ScaffoldIIS $hostNameForKretaIdp $hostIpForKretaIdp $iisApplicationPoolNameForKretaIdp $iisApplicationPoolDotNetVersionForKretaIdp $iisApplicationNameForKretaIdp $evaluatedWebPathForKretaIdp

    Write-Host "---------------------Set SSL for IDP---------------------------------------------"
    AddSslBindingToIdpAndAddAsTrustedCert $iisApplicationPoolNameForKretaIdp $hostNameForKretaIdp

    Write-Host "---------------------Scaffold LocalDB For Idp------------------------------------"
    CheckAndInstallLocalDb $localDbForIdp

    Write-Host "---------------------Restart IIS-------------------------------------------------"
    ResetIIS

    Write-Host "---------------------Reset Environment-------------------------------------------"
    ResetEnvironment
}
finally
{
    Write-Host "---------------------Stop Logging------------------------------------------------"
    StopLogging
}

#endregion